.. module:: cobyqa

Optimization solver
===================

.. currentmodule:: cobyqa

This module is the entry point of the COBYQA solver.
Most users will only need to use the `minimize` function.

.. autosummary::
    :toctree: generated/

    minimize
    show_versions
